==> libreoffice_4.2.8.orig.tar.xz: libreoffice-4.2.8/odk/examples/DevelopersGuide/OfficeDev/Linguistic/XMeaning_impl.java <==
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  the BSD license.
 *
 *  Copyright 2000, 2010 Oracle and/or its affiliates.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. Neither the name of Sun Microsystems, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 *  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 *  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 *  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************/



public class XMeaning_impl implements
    com.sun.star.linguistic2.XMeaning
{
    String      aMeaning;
    String[]    aSynonyms;

    public XMeaning_impl ( String aMeaning, String[] aSynonyms )
    {
        this.aMeaning   = aMeaning;
        this.aSynonyms  = aSynonyms;

        //!! none of these cases should ever occur!
        //!! values provided only for safety
        if (this.aMeaning == null)
            this.aMeaning = new String();

        // a meaning without synonyms may be OK though.
        // still for safety an empty existing array has to be provided.
        if (this.aSynonyms == null)
            this.aSynonyms = new String[]{};
    }

    // XMeaning
    public String getMeaning() throws com.sun.star.uno.RuntimeException
    {
        return aMeaning;
    }
    public String[] querySynonyms() throws com.sun.star.uno.RuntimeException
    {
        return aSynonyms;
    }
};

==> libreoffice_5.1.2.orig.tar.xz: libreoffice-5.1.2/odk/examples/DevelopersGuide/OfficeDev/Linguistic/XMeaning_impl.java <==
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  the BSD license.
 *
 *  Copyright 2000, 2010 Oracle and/or its affiliates.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. Neither the name of Sun Microsystems, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 *  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 *  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 *  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************/



public class XMeaning_impl implements
    com.sun.star.linguistic2.XMeaning
{
    private String      aMeaning;
    private String[]    aSynonyms;

    public XMeaning_impl ( String aMeaning, String[] aSynonyms )
    {
        this.aMeaning   = aMeaning;
        this.aSynonyms  = aSynonyms;

        //!! none of these cases should ever occur!
        //!! values provided only for safety
        if (this.aMeaning == null)
            this.aMeaning = "";

        // a meaning without synonyms may be OK though.
        // still for safety an empty existing array has to be provided.
        if (this.aSynonyms == null)
            this.aSynonyms = new String[]{};
    }

    // XMeaning
    public String getMeaning() throws com.sun.star.uno.RuntimeException
    {
        return aMeaning;
    }
    public String[] querySynonyms() throws com.sun.star.uno.RuntimeException
    {
        return aSynonyms;
    }
}
